PasswordGuardException class

Base exception for all password_guard errors.

Implemented types
Implementers

Constructors

PasswordGuardException(String message, {Object? cause})
const

Properties

cause Object?
Optional underlying cause.
final
hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable message describing what went wrong.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited